@@ -1,14 +1,6 @@
 
 .onLoad <- function(libname, pkgname) {
 
-	if (.Platform$OS.type == "windows" && 
-		interactive() && 
-		!isTRUE(getOption("gsubfn.noVignetteMenu")) && 
-		file.exists(system.file(package = "Zelig")) &&
-		file.exists(system.file("Meta", "vignette.rds", package = pkgname))) {
-		  Zelig:::addVigs2WinMenu(pkgname)
-	}
-
 	gsubfn.engine <- getOption("gsubfn.engine")
 	# if gsubfn.engine was not set to "R" then check if tcltk can be used
     if ( ! identical(gsubfn.engine, "R") ) {
